% Calculates the d_min and NRL statistics with the corresponding p-values.
% Please cite as:
% "Nonparametric Testing for Serial Independence Using the NRL Statistic"
% Communication in Statistics - Simulation and Computation
% 
% Witold Orzeszko
% Nicolaus Copernicus University in Torun, Poland
% University e-mail: witold.orzeszko@umk.pl
% Homepage: witold.orzeszko.wneiz.umk.pl
%
% August 2, 2016.    
    clear all
    x=xlsread('data.xlsx');
    N_series=numel(x(1,:)); %number of investigated series in data.xlsx
    N_perm=1000;  %number of permutations
    lag=1;
    dim_max=5; %maximal embedding dimension m
    statistic=zeros(N_series,2*dim_max-1);
    pvalue=zeros(N_series,2*dim_max-1);
for i=1:N_series   
    i
    series=x(:,i);
    numElem = numel(series);
    xSim=zeros(numElem,N_perm);
    for k=1:N_perm   
        xSim(:,k) = series(randperm(numElem));            
    end 
    for j=2:dim_max
        temp=NRL(j, lag, series);
        statistic(i,j-1)=temp(1);  %the nrl statistic
        statistic(i,dim_max+j-1)=temp(2);  %the d_min statistic 
        nrlSim=zeros(N_perm,3);
        for k=1:N_perm
            nrlSim(k,:)=NRL(j,lag,xSim(:,k));
        end
        pvalue(i,j-1) = numel(find(nrlSim(:,1)< statistic(i,j-1)))/N_perm; %pvalue for the nrl statistic
        pvalue (i,dim_max+j-1)= numel(find(nrlSim(:,2)< statistic(i,dim_max+j-1)))/N_perm; %pvalue for the d_min statistic
        end 
end
    save nrl.dat statistic -ASCII
    save pvalue.dat pvalue -ASCII